@@ -22,10 +22,13 @@
 #define SIZEOF_PTR 4
 #define SIZEOF_SHORT 2
 #define SIZEOF_LONGLONG 8
+#define INT64_LITERAL(s) s ## LL
 #undef ARCH_BIG_ENDIAN
 #define ARCH_ALIGN_DOUBLE
 #define ARCH_ALIGN_INT64
 #define ASM_CFI_SUPPORTED
+#define PROFINFO_WIDTH 26
+#define CAML_WITH_CPLUGINS
 #define OCAML_OS_TYPE "Unix"
 #define OCAML_STDLIB_DIR "/usr/lib/ocaml"
 #define POSIX_SIGNALS
@@ -54,6 +57,7 @@
 #define HAS_TRUNCATE
 #define HAS_SYS_SELECT_H
 #define HAS_SELECT
+#define HAS_NANOSLEEP
 #define HAS_SYMLINK
 #define HAS_WAITPID
 #define HAS_WAIT4
